@@ -495,6 +495,13 @@ wvApplySprmFromBucket (wvVersion ver, U16 sprm, PAP * apap, CHP * achp,
       case sprmPFAdjustRight:
 	  apap->fAdjustRight = bread_8ubit (pointer, pos);
 	  break;
+      case sprmPRsid:
+	  /*  apap->rsid = */ bread_32ubit (pointer, pos);
+	  break;
+      case sprmPItap:
+		 apap->fInTable =bread_32ubit (pointer, pos); /*  Need to introduce apap->fInTableW97? */ 
+	     apap->fTtp++;  /* this is probably wrong, but currently needed for bug #11433 */
+	  break;
 	  /*End of PAP */
 
 
@@ -736,6 +743,9 @@ wvApplySprmFromBucket (wvVersion ver, U16 sprm, PAP * apap, CHP * achp,
 	  achp->lidFE = achp->lid;
 	  wvTrace (("lid is %x\n", achp->lidDefault));
 	  break;
+      case sprmCRsidText:
+		 bread_32ubit (pointer, pos);
+	  break;
 
 	  /* BiDi */
 
@@ -1046,10 +1056,8 @@ wvApplySprmFromBucket (wvVersion ver, U16 sprm, PAP * apap, CHP * achp,
       case sprmCCharScale:	/* ???? */
       case sprmNoop:		/* no operand */
 	  break;
-      case 25703:
-         apap->fTtp++;
-         break; 
       default:
+	wvTrace(("unknown sprm: %d\n", sprm));
 	  wvEatSprm (sprm, pointer, pos);
 	  break;
       }
